@@ -35,12 +35,14 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 from DLStudio import *
 
 dls = DLStudio(
-                  dataroot = "/home/kak/ImageDatasets/CIFAR-10/",
+#                  dataroot = "/home/kak/ImageDatasets/CIFAR-10/",
+                  dataroot = "./data/CIFAR-10/",
                   image_size = [32,32],
                   path_saved_model = "./saved_model",
                   momentum = 0.9,
                   learning_rate = 1e-4,
                   epochs = 6,
+#                  epochs = 1,                 ## just for classroom demos
                   batch_size = 4,
                   classes = ('plane','car','bird','cat','deer',
                              'dog','frog','horse','ship','truck'),
@@ -54,17 +56,18 @@ skip_con = DLStudio.SkipConnections( dl_studio = dls )
 #exp_skip.load_cifar_10_dataset_with_augmentation()
 skip_con.load_cifar_10_dataset()
 
-model = skip_con.BMEnet(skip_connections=True, depth=32)
-
-number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-print("\n\nThe number of learnable parameters in the model: %d\n\n" % number_of_learnable_params)
-
-num_layers = len(list(model.parameters()))
-print("\n\nThe number of layers in the model: %d\n\n" % num_layers)
+#model = skip_con.BMEnet(skip_connections=True, depth=32)         ## if you want to use skips
+model = skip_con.BMEnet(skip_connections=False, depth=32)         ## if you don't want to use skips
 
+## display network properties
 dls.show_network_summary(model)
+number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
+print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
+num_layers = len(list(model.parameters()))
+print("\nThe number of layers in the model: %d" % num_layers)
 
-skip_con.run_code_for_training(model)
+## training and testing
+skip_con.run_code_for_training(model, display_images=False)
 
 skip_con.run_code_for_testing(model)
 
